(function($) {
  Drupal.behaviors.viewsResizableColumns = {
    attach: function(context) {
      // Select tables that haven't been processed yet using once
      const tables = once('views-resizable-columns', 'table.views-table', context);
      //console.log('Number of tables found:', tables.length);
      tables.forEach(function(table) {
        const $table = $(table);
        // Get the unique view ID from the parent container for LocalStorage key
        const viewId = $table.attr('data-view-id');
        const displayId = $table.attr('data-display-id');
        const uniqueKey = `views-resizable-${viewId}-${displayId}`;
        // Load saved widths from LocalStorage
        const savedWidths = localStorage.getItem(uniqueKey);
        if (savedWidths) {
          try {
            const widths = JSON.parse(savedWidths);
            $table.find('thead th').each(function(index) {
              if (widths[index] !== undefined) {
                $(this).width(widths[index]);
                //console.log('Applied width to column', index, ':', widths[index]);
              }
            });
          } catch (e) {
            console.error('Error parsing saved widths:', e);
          }
        }

        // Add resize handles to each table header
        $table.find('thead th').each(function() {
          const $th = $(this);
          const $handle = $('<div class="resize-handle"></div>');
          $th.append($handle);
          //console.log('Resize handle added to th:', $th.find('.resize-handle').length);
          $handle.on('mousedown', function(e) {
            e.preventDefault();
            $('body').addClass('resizing');
            const startX = e.pageX;
            const originalWidth = $th.width();
            const minWidth = 20;

            $(document).on('mousemove.resizable', function(e) {
              const newWidth = Math.max(minWidth, originalWidth + (e.pageX - startX));
              $th.width(newWidth);
            });

            $(document).on('mouseup.resizable', function() {
              $('body').removeClass('resizing');
              $(document).off('mousemove.resizable');
              $(document).off('mouseup.resizable');
              // Save the current widths to LocalStorage
              const widths = [];
              $table.find('thead th').each(function() {
                widths.push($(this).width());
              });
              localStorage.setItem(uniqueKey, JSON.stringify(widths));
              //console.log('Saved widths for', uniqueKey, ':', widths);
            });
          });
        });
      });
    }
  };
})(jQuery);
